@@ -25,7 +25,6 @@
 #ifndef SESSION_H
 #define SESSION_H
 
-
 #include <QStringList>
 #include <QWidget>
 
@@ -283,6 +282,9 @@ public:
     /** Returns the text of the icon associated with this session. */
     QString iconText() const;
 
+    /** Flag if the title/icon was changed by user/shell. */
+    bool isTitleChanged() const;
+
     /** Specifies whether a utmp entry should be created for the pty used by this session. */
     void setAddToUtmp(bool);
 
@@ -363,6 +365,13 @@ public:
 //  void cancelZModem();
 //  bool isZModemBusy() { return _zmodemBusy; }
 
+    /**
+     * Returns a pty slave file descriptor.
+     * This can be used for display and control
+     * a remote terminal.
+     */
+    int getPtySlaveFd() const;
+
 public slots:
 
     /**
@@ -372,6 +381,13 @@ public slots:
      */
     void run();
 
+    /**
+     * Starts the terminal session for "as is" PTY
+     * (without the direction a data to internal terminal process).
+     * It can be used for control or display a remote/external terminal.
+     */
+    void runEmptyPTY();
+
     /**
      * Closes the terminal session.  This sends a hangup signal
      * (SIGHUP) to the terminal process and causes the done(Session*)
@@ -473,7 +489,7 @@ private slots:
     void monitorTimerDone();
 
     void onViewSizeChange(int height, int width);
-    void onEmulationSizeChange(int lines , int columns);
+    void onEmulationSizeChange(QSize);
 
     void activityStateSet(int);
 
@@ -516,6 +532,7 @@ private:
 
     QString        _iconName;
     QString        _iconText; // as set by: echo -en '\033]1;IconText\007
+    bool           _isTitleChanged; ///< flag if the title/icon was changed by user
     bool           _addToUtmp;
     bool           _flowControl;
     bool           _fullScripting;
@@ -543,6 +560,8 @@ private:
 
     static int lastSessionId;
 
+    int ptySlaveFd;
+
 };
 
 /**
