@@ -258,7 +258,7 @@ void QTermWidget::init(int startnow)
 
     // That's OK, FilterChain's dtor takes care of UrlFilter.
     UrlFilter *urlFilter = new UrlFilter();
-    connect(urlFilter, SIGNAL(activated(QUrl)), this, SIGNAL(urlActivated(QUrl)));
+    connect(urlFilter, &UrlFilter::activated, this, &QTermWidget::urlActivated);
     m_impl->m_terminalDisplay->filterChain()->addFilter(urlFilter);
 
     m_searchBar = new SearchBar(this);
@@ -296,11 +296,13 @@ void QTermWidget::init(int startnow)
     m_searchBar->setFont(font);
 
     setScrollBarPosition(NoScrollBar);
+    setKeyboardCursorShape(BlockCursor);
 
     m_impl->m_session->addView(m_impl->m_terminalDisplay);
 
     connect(m_impl->m_session, SIGNAL(resizeRequest(QSize)), this, SLOT(setSize(QSize)));
     connect(m_impl->m_session, SIGNAL(finished()), this, SLOT(sessionFinished()));
+    connect(m_impl->m_session, &Session::titleChanged, this, &QTermWidget::titleChanged);
 }
 
 
@@ -333,6 +335,14 @@ void QTermWidget::setTerminalOpacity(qreal level)
     m_impl->m_terminalDisplay->setOpacity(level);
 }
 
+void QTermWidget::setTerminalBackgroundImage(QString backgroundImage)
+{
+    if (!m_impl->m_terminalDisplay)
+        return;
+
+    m_impl->m_terminalDisplay->setBackgroundImage(backgroundImage);
+}
+
 void QTermWidget::setShellProgram(const QString &progname)
 {
     if (!m_impl->m_session)
@@ -432,6 +442,11 @@ QStringList QTermWidget::availableColorSchemes()
     return ret;
 }
 
+void QTermWidget::addCustomColorSchemeDir(const QString& custom_dir)
+{
+    ColorSchemeManager::instance()->addCustomColorSchemeDir(custom_dir);
+}
+
 void QTermWidget::setSize(const QSize &size)
 {
     if (!m_impl->m_terminalDisplay)
@@ -451,7 +466,7 @@ void QTermWidget::setScrollBarPosition(ScrollBarPosition pos)
 {
     if (!m_impl->m_terminalDisplay)
         return;
-    m_impl->m_terminalDisplay->setScrollBarPosition((TerminalDisplay::ScrollBarPosition)pos);
+    m_impl->m_terminalDisplay->setScrollBarPosition(pos);
 }
 
 void QTermWidget::scrollToEnd()
@@ -478,7 +493,6 @@ void QTermWidget::sessionFinished()
     emit finished();
 }
 
-
 void QTermWidget::copyClipboard()
 {
     m_impl->m_terminalDisplay->copyClipboard();
@@ -637,7 +651,40 @@ Filter::HotSpot* QTermWidget::getHotSpotAt(int row, int column) const
     return m_impl->m_terminalDisplay->filterChain()->hotSpotAt(row, column);
 }
 
+QList<QAction*> QTermWidget::filterActions(const QPoint& position)
+{
+    return m_impl->m_terminalDisplay->filterActions(position);
+}
+
 int QTermWidget::getPtySlaveFd() const
 {
     return m_impl->m_session->getPtySlaveFd();
 }
+
+void QTermWidget::setKeyboardCursorShape(KeyboardCursorShape shape)
+{
+    if (!m_impl->m_terminalDisplay)
+        return;
+    m_impl->m_terminalDisplay->setKeyboardCursorShape(shape);
+}
+
+QString QTermWidget::title() const
+{
+    QString title = m_impl->m_session->userTitle();
+    if (title.isEmpty())
+        title = m_impl->m_session->title(Konsole::Session::NameRole);
+    return title;
+}
+
+QString QTermWidget::icon() const
+{
+    QString icon = m_impl->m_session->iconText();
+    if (icon.isEmpty())
+        icon = m_impl->m_session->iconName();
+    return icon;
+}
+
+bool QTermWidget::isTitleChanged() const
+{
+    return m_impl->m_session->isTitleChanged();
+}
